/** @typedef {Object<string,any>} Result */
/** @typedef {import('web-vitals').Metric | Object<string,any>} Metric */
/** @typedef {{ effectiveType: 'slow-2g' | '2g' | '3g' | '4g', rtt: number, downlink: number }} NetworkInformation */
/**
 * Create Web Vitals API reporter, that accepts `Metric` values and sends it to `url`
 * using `navigator.sendBeackon` when avaiable or fallbacks back to XMLHttpRequest.
 *
 * The function sends request only once.
 * Use `onSend` to implement a custom logic.
 *
 * @param {string} url
 * @param {{ initial?: object, mapMetric?: (metric: Metric, result: Result) => object, onSend?: (url: string, values: Result) => any }} [opts]
 * @return {(metric: Metric) => void}
 */
export function createApiReporter(url: string, opts?: {
    initial?: object;
    mapMetric?: (metric: Metric, result: Result) => object;
    onSend?: (url: string, values: Result) => any;
}): (metric: Metric) => void;
/**
 * Get device information.
 * - Effective connection type: https://developer.mozilla.org/en-US/docs/Web/API/NetworkInformation
 * - Device memory: https://developer.mozilla.org/en-US/docs/Web/API/Navigator/deviceMemory
 */
export function getDeviceInfo(): {
    url: string;
    referrer: string;
    userAgent: string;
    memory: number;
    cpus: number;
    connection: {
        effectiveType: "slow-2g" | "2g" | "3g" | "4g";
        rtt: number;
        downlink: number;
    } | {
        effectiveType?: undefined;
        rtt?: undefined;
        downlink?: undefined;
    };
};
export type Result = {
    [x: string]: any;
};
export type Metric = import("web-vitals").Metric | {
    [x: string]: any;
};
export type NetworkInformation = {
    effectiveType: 'slow-2g' | '2g' | '3g' | '4g';
    rtt: number;
    downlink: number;
};
